@@ -1,7 +1,7 @@
 package Text::WideChar::Util;
 
-our $DATE = '2015-07-27'; # DATE
-our $VERSION = '0.15'; # VERSION
+our $DATE = '2015-07-29'; # DATE
+our $VERSION = '0.16'; # VERSION
 
 use 5.010001;
 use locale;
@@ -75,6 +75,9 @@ sub _get_indent_width {
     $w;
 }
 
+# 3002 = IDEOGRAPHIC FULL STOP
+# ff0c = FULLWIDTH COMMA
+
 our $re_cjk = qr/(?:
                      \p{Block=CJK_Compatibility}
                  |   \p{Block=CJK_Compatibility_Forms}
@@ -87,7 +90,7 @@ our $re_cjk = qr/(?:
                  |   \p{Block=CJK_Unified_Ideographs_Extension_A}
                  |   \p{Block=CJK_Unified_Ideographs_Extension_B}
                      #|   \p{Block=CJK_Unified_Ideographs_Extension_C}
-                     [\N{IDEOGRAPHIC FULL STOP}\N{FULLWIDTH COMMA}]
+                     [\x{3002}\x{ff0c}]
                  )/x;
 our $re_cjk_class = qr/[
                            \p{Block=CJK_Compatibility}
@@ -100,8 +103,8 @@ our $re_cjk_class = qr/[
                            \p{Block=CJK_Unified_Ideographs}
                            \p{Block=CJK_Unified_Ideographs_Extension_A}
                            \p{Block=CJK_Unified_Ideographs_Extension_B}
-                           \N{IDEOGRAPHIC FULL STOP}
-                           \N{FULLWIDTH COMMA}
+                           \x{3002}
+                           \x{ff0c}
                       ]/x;
 our $re_cjk_negclass = qr/[^
                               \p{Block=CJK_Compatibility}
@@ -114,8 +117,8 @@ our $re_cjk_negclass = qr/[^
                               \p{Block=CJK_Unified_Ideographs}
                               \p{Block=CJK_Unified_Ideographs_Extension_A}
                               \p{Block=CJK_Unified_Ideographs_Extension_B}
-                              \N{IDEOGRAPHIC FULL STOP}
-                              \N{FULLWIDTH COMMA}
+                              \x{3002}
+                              \x{ff0c}
                       ]/x;
 
 sub _wrap {
@@ -418,7 +421,7 @@ Text::WideChar::Util - Routines for text containing wide characters
 
 =head1 VERSION
 
-This document describes version 0.15 of Text::WideChar::Util (from Perl distribution Text-WideChar-Util), released on 2015-07-27.
+This document describes version 0.16 of Text::WideChar::Util (from Perl distribution Text-WideChar-Util), released on 2015-07-29.
 
 =head1 SYNOPSIS
 
@@ -562,7 +565,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Text-WideC
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Text-WideChar-Util>.
+Source repository is at L<https://github.com/perlancar/perl-Text-WideChar-Util>.
 
 =head1 BUGS
 
